@@ -22,14 +22,14 @@
  * should behave exactly as their counterparts. There are also extensions
  * that aren't portable at all (like strirstr etc.).
  * The proper behaviour in a configure script is as follows:
- *    AC_CHECK_FUNC(strrchr,AC_DEFINE(strrchr,FP_strrchr))
+ *    AC_CHECK_FUNC(strrchr,AC_DEFINE(strrchr,_FP_strrchr))
  * This way, the (probably less efficient) replacements will only be used
  * where it is not provided by the default libraries. Be aware that this
  * does not work with replacements that just shadow wrong behaviour (like
- * FP_free) or provide extended functionality (FP_gets).
+ * _FP_free) or provide extended functionality (FP_gets).
  * The above is not used in the uuenview/uudeview configuration script,
  * since both only use the replacement functions in non-performance-cri-
- * tical sections (except for FP_tempnam and FP_strerror, where some
+ * tical sections (except for _FP_tempnam and FP_strerror, where some
  * functionality of the original would be lost).
  */
 
@@ -73,7 +73,7 @@ char * fptools_id = "$Id$";
  */
 
 void TOOLEXPORT
-FP_free (void *ptr)
+_FP_free (void *ptr)
 {
   if (ptr) free (ptr);
 }
@@ -83,7 +83,7 @@ FP_free (void *ptr)
  */
 
 char * TOOLEXPORT
-FP_strdup (char *string)
+_FP_strdup (char *string)
 {
   char *result;
 
@@ -104,7 +104,7 @@ FP_strdup (char *string)
  */
 
 char * TOOLEXPORT
-FP_strncpy (char *dest, char *src, int length)
+_FP_strncpy (char *dest, char *src, int length)
 {
   char *odest=dest;
   if (src == NULL || dest == NULL || length-- <= 0)
@@ -122,7 +122,7 @@ FP_strncpy (char *dest, char *src, int length)
  */
 
 void * TOOLEXPORT
-FP_memdup (const void *ptr, int len)
+_FP_memdup (void *ptr, int len)
 {
   void *result;
 
@@ -140,9 +140,8 @@ FP_memdup (const void *ptr, int len)
  * case-insensitive compare
  */
 
-#ifndef FP_stricmp
 int TOOLEXPORT
-FP_stricmp (const char *str1, const char *str2)
+_FP_stricmp (char *str1, char *str2)
 {
   if (str1==NULL || str2==NULL)
     return -1;
@@ -155,55 +154,52 @@ FP_stricmp (const char *str1, const char *str2)
   }
   return (tolower (*str1) - tolower (*str2));
 }
-#endif
 
-#ifndef FP_strnicmp
 int TOOLEXPORT
-FP_strnicmp (const char *str1, const char *str2, int count)
+_FP_strnicmp (char *str1, char *str2, int count)
 {
-  int d;
-
-  if (!str1 || !str2)
+  if (str1==NULL || str2==NULL)
     return -1;
 
-  while (count--) {
-    if (!*str1)
-      return -1;
-
-    d = tolower (*str1) - tolower (*str2);
-    if (d)
-      return d;
-
+  while (*str1 && count) {
+    if (tolower(*str1) != tolower(*str2))
+      break;
     str1++;
     str2++;
+    count--;
   }
-
-  return 0;
+  return count ? (tolower (*str1) - tolower (*str2)) : 0;
 }
-#endif
 
-int TOOLEXPORT
-FP_strnicmp_fast (const char *str1, const char *str2, int count)
+/*
+ * autoconf says this function might be a compatibility problem
+ */
+
+char * TOOLEXPORT
+_FP_strstr (char *str1, char *str2)
 {
-  if (!str1 || !str2)
-    return -1;
+  char *ptr1, *ptr2;
 
-  while (count--) {
-    if (!*str1)
-      return -1;
+  if (str1==NULL)
+    return NULL;
+  if (str2==NULL)
+    return str1;
 
-    if ((*str1 ^ *str2) & 0xdf)
-      return (*str1 & 0xdf) - (*str2 & 0xdf);
+  while (*(ptr1=str1)) {
+    for (ptr2=str2;
+	 *ptr1 && *ptr2 && *ptr1==*ptr2;
+	 ptr1++, ptr2++)
+      /* empty loop */ ;
 
+    if (*ptr2 == '\0')
+      return str1;
     str1++;
-    str2++;
   }
-
-  return 0;
+  return NULL;
 }
 
 char * TOOLEXPORT
-FP_strpbrk (char *str, char *accept)
+_FP_strpbrk (char *str, char *accept)
 {
   char *ptr;
 
@@ -225,7 +221,7 @@ FP_strpbrk (char *str, char *accept)
  */
 
 char * TOOLEXPORT
-FP_strtok (char *str1, char *str2)
+_FP_strtok (char *str1, char *str2)
 {
   static char *optr;
   char *ptr;
@@ -261,9 +257,8 @@ FP_strtok (char *str1, char *str2)
  * case insensitive strstr.
  */
 
-#ifndef FP_stristr
 char * TOOLEXPORT
-FP_stristr (char *str1, char *str2)
+_FP_stristr (char *str1, char *str2)
 {
   char *ptr1, *ptr2;
 
@@ -284,33 +279,31 @@ FP_stristr (char *str1, char *str2)
   }
   return NULL;
 }
-#endif
 
 /*
  * Nice fake of the real (non-standard) one
  */
 
 char * TOOLEXPORT
-FP_strrstr (const char *ptr, const char *str)
+_FP_strrstr (char *ptr, char *str)
 {
-  const char *found=NULL, *new, *iter=ptr;
+  char *found=NULL, *new, *iter=ptr;
 
   if (ptr==NULL || str==NULL)
     return NULL;
 
   if (*str == '\0')
-    return (char *)ptr;
+    return ptr;
 
-  while ((new = FP_strstr (iter, str)) != NULL) {
+  while ((new = _FP_strstr (iter, str)) != NULL) {
     found = new;
     iter  = new + 1;
   }
-
-  return (char *)found;
+  return found;
 }
 
 char * TOOLEXPORT
-FP_strirstr (char *ptr, char *str)
+_FP_strirstr (char *ptr, char *str)
 {
   char *found=NULL, *iter=ptr, *new;
 
@@ -319,7 +312,7 @@ FP_strirstr (char *ptr, char *str)
   if (*str == '\0')
     return ptr;
 
-  while ((new = FP_stristr (iter, str)) != NULL) {
+  while ((new = _FP_stristr (iter, str)) != NULL) {
     found = new;
     iter  = new + 1;
   }
@@ -331,7 +324,7 @@ FP_strirstr (char *ptr, char *str)
  */
 
 char * TOOLEXPORT
-FP_stoupper (char *input)
+_FP_stoupper (char *input)
 {
   char *iter = input;
 
@@ -346,7 +339,7 @@ FP_stoupper (char *input)
 }
 
 char * TOOLEXPORT
-FP_stolower (char *input)
+_FP_stolower (char *input)
 {
   char *iter = input;
 
@@ -365,7 +358,7 @@ FP_stolower (char *input)
  */
 
 int TOOLEXPORT
-FP_strmatch (char *string, char *pattern)
+_FP_strmatch (char *string, char *pattern)
 {
   char *p1 = string, *p2 = pattern;
 
@@ -395,9 +388,9 @@ FP_strmatch (char *string, char *pattern)
 }
 
 char * TOOLEXPORT
-FP_strrchr (const char *string, int tc)
+_FP_strrchr (char *string, int tc)
 {
-  const char *ptr;
+  char *ptr;
 
   if (string == NULL || !*string)
     return NULL;
@@ -408,7 +401,7 @@ FP_strrchr (const char *string, int tc)
     ptr--;
 
   if (*ptr == tc)
-    return (char *)ptr;
+    return ptr;
 
   return NULL;
 }
@@ -419,16 +412,16 @@ FP_strrchr (const char *string, int tc)
  */
 
 char * TOOLEXPORT
-FP_cutdir (char *filename)
+_FP_cutdir (char *filename)
 {
   char *ptr;
 
   if (filename == NULL)
     return NULL;
 
-  if ((ptr = FP_strrchr (filename, '/')) != NULL)
+  if ((ptr = _FP_strrchr (filename, '/')) != NULL)
     ptr++;
-  else if ((ptr = FP_strrchr (filename, '\\')) != NULL)
+  else if ((ptr = _FP_strrchr (filename, '\\')) != NULL)
     ptr++;
   else
     ptr = filename;
@@ -438,53 +431,103 @@ FP_cutdir (char *filename)
 
 /*
  * My own fgets function. It handles all kinds of line terminators
- * properly: LF (Unix), CRLF (DOS) and CR (Mac).
+ * properly: LF (Unix), CRLF (DOS) and CR (Mac). In all cases, the
+ * terminator is replaced by a single LF
  */
-/* (schmorp) the buffer is always written to, and no LF is stored at the end */
-/* also, if the buffer is too short, the remaining line is skipped */
-ecb_hot char * TOOLEXPORT
-FP_fgets (char *buf, int n, FILE *stream)
+
+char * TOOLEXPORT
+_FP_fgets (char *buf, int n, FILE *stream)
 {
-  char *ptr = buf;
-  char *end = buf + n - 1;
+  char *obp = buf;
+  int c;
 
   /* shield against buffer overflows caused by "255 - bytes_left"-kind of bugs when bytes_left > 255 */
   if (n <= 0)
-    return 0;
+    return NULL;
 
-  for (;;)
-    {
-      int c = FP_getc (stream);
+  if (feof (stream))
+    return NULL;
 
-      if (ecb_expect_false (c <= '\015')) /* EOF is < 0x20, too */
-        {
-          /* ctlchar */
-
-          if (c == '\012')
-            /* LF, nothing following */
-            break;
-          else if (c == '\015')
-            {
-              /* CR, possibly CRLF, skip following LF */
-              c = FP_getc (stream);
-
-              if (c != '\012') /* CR LF? */
-                ungetc (c, stream);
-
-              break;
-            }
-          else if (c == EOF)
-            {
-              *ptr = 0;
-              return 0;
-            }
-        }
-
-      *ptr = c;
-      ptr += ptr < end; /* this is hopefully branch-free, and fast */
+  while (--n && !feof (stream)) {
+    if ((c = fgetc (stream)) == EOF) {
+      if (ferror (stream))
+	return NULL;
+      else {
+	if (obp == buf)
+	  return NULL;
+	*buf = '\0';
+	return obp;
+      }
     }
+    if (c == '\015') { /* CR */
+      /*
+       * Peek next character. If it's no LF, push it back.
+       * ungetc(EOF, stream) is handled correctly according
+       * to the manual page
+       */
+      if ((c = fgetc (stream)) != '\012')
+	if (!feof (stream))
+	  ungetc (c, stream);
+      *buf++ = '\012';
+      *buf   = '\0';
+      return obp;
+    }
+    else if (c == '\012') { /* LF */
+      *buf++ = '\012';
+      *buf   = '\0';
+      return obp;
+    }
+    /*
+     * just another standard character
+     */
+    *buf++ = c;
+  }
 
-  *ptr = 0;
-  return buf;
+  /*
+   * n-1 characters already transferred
+   */
+
+  *buf = '\0';
+
+  /*
+   * If a line break is coming up, read it
+   */
+
+  if (!feof (stream)) {
+    if ((c = fgetc (stream)) == '\015' && !feof (stream)) {
+      if ((c = fgetc (stream)) != '\012' && !feof (stream)) {
+	ungetc (c, stream);
+      }
+    }
+    else if (c != '\012' && !feof (stream)) {
+      ungetc (c, stream);
+    }
+  }
+
+  return obp;
 }
 
+/*
+ * A replacement strerror function that just returns the error code
+ */
+
+char * TOOLEXPORT
+_FP_strerror (int errcode)
+{
+  static char number[8];
+
+  sprintf (number, "%03d", errcode);
+
+  return number;
+}
+#ifndef HAVE_MKSTEMP
+/*
+ * tempnam is not ANSI, but tmpnam is. Ignore the prefix here.
+ */
+
+char * TOOLEXPORT
+_FP_tempnam (char *dir, char *pfx)
+{
+  return _FP_strdup (tmpnam (NULL));
+}
+#endif /* HAVE_MKSTEMP */
