@@ -81,12 +81,10 @@
 #include <fptools.h>
 #include <uustring.h>
 
-#include "safealloc.c"
-
 char * uulib_id = "$Id$";
 
 #ifdef SYSTEM_WINDLL
-BOOL _export WINAPI
+BOOL _export WINAPI 
 DllEntryPoint (HINSTANCE hInstance, DWORD seginfo,
 	       LPVOID lpCmdLine)
 {
@@ -128,8 +126,6 @@ void *uu_FileCBArg = NULL;
 void *uu_FFCBArg   = NULL;
 void *uu_FNCBArg;
 
-int uu_autocheck = 1;           /* call UUCheckGlobaList after every part */
-
 /* I/O buffer sizes */
 int uu_rbuf = 0;
 int uu_wbuf = 0;
@@ -244,7 +240,7 @@ static allomap toallocate[] = {
   { &uuestr_itemp,       256 },  /* from uuencode.c:UUEncodeStream() */
   { &uuestr_otemp,      1024 },
   { &uulib_msgstring,   1024 },  /* from uulib.c:UUMessage() */
-  { &uuncdl_fulline,    1201 },  /* from uunconc.c:UUDecodeLine() */
+  { &uuncdl_fulline,    1200 },  /* from uunconc.c:UUDecodeLine() */
   { &uuncdp_oline,      3600 },  /* from uunconc.c:UUDecodePart() */
   { &uunconc_UUxlat,     256 * sizeof (int) },  /* from uunconc.c:toplevel */
   { &uunconc_UUxlen,      64 * sizeof (int) },
@@ -256,10 +252,10 @@ static allomap toallocate[] = {
   { &uuscan_shlline2,   1024 },  /* from uuscan.c:ScanHeaderLine() */
   { &uuscan_pvvalue,     300 },  /* from uuscan.c:ParseValue() */
   { &uuscan_phtext,      300 },  /* from uuscan.c:ParseHeader() */
-  { &uuscan_sdline,     1025 },  /* from uuscan.c:ScanData(), +1 for UURepairData */
-  { &uuscan_sdbhds1,    1300 },  /* 1024 for line in UUScan + 256 potential overhead UUDecodeLine */
-  { &uuscan_sdbhds2,    1300 },  /* 1024 for line in UUScan + 256 potential overhead UUDecodeLine */
-  { &uuscan_spline,     1024 },  /* from uuscan.c:ScanPart() */
+  { &uuscan_sdline,      300 },  /* from uuscan.c:ScanData() */
+  { &uuscan_sdbhds1,     300 },
+  { &uuscan_sdbhds2,     300 },
+  { &uuscan_spline,      300 },  /* from uuscan.c:ScanPart() */
   { &uuutil_bhwtmp,      300 },  /* from uuutil.c:UUbhwrite() */
   { NULL, 0 }
 };
@@ -277,7 +273,7 @@ UUMessage (va_alist)
   va_dcl
 #endif
 {
-  int msgofs;
+  char *msgptr;
 #if defined(STDC_HEADERS) || defined(HAVE_STDARG_H)
   va_list ap;
 
@@ -295,16 +291,16 @@ UUMessage (va_alist)
 #endif
 
   if (uu_debug) {
-    snprintf (uulib_msgstring, 1024,  "%s(%d): %s", file, line, msgnames[level]);
-    msgofs = strlen (uulib_msgstring);
+    sprintf (uulib_msgstring, "%s(%d): %s", file, line, msgnames[level]);
+    msgptr = uulib_msgstring + strlen (uulib_msgstring);
   }
   else {
-    snprintf (uulib_msgstring, 1024, "%s", msgnames[level]);
-    msgofs = strlen (uulib_msgstring);
+    sprintf (uulib_msgstring, "%s", msgnames[level]);
+    msgptr = uulib_msgstring + strlen (uulib_msgstring);
   }
 
   if (uu_MsgCallback && (level>UUMSG_NOTE || uu_verbose)) {
-    vsnprintf (uulib_msgstring + msgofs, 1024 - msgofs, format, ap);
+    vsprintf (msgptr, format, ap);
 
     (*uu_MsgCallback) (uu_MsgCBArg, uulib_msgstring, level);
   }
@@ -398,13 +394,13 @@ UUInitialize (void)
     *(aiter->ptr) = NULL;
 
   for (aiter=toallocate; aiter->ptr; aiter++) {
-    if ((*(aiter->ptr) = (char *) safe_alloc (aiter->size)) == NULL) {
+    if ((*(aiter->ptr) = (char *) malloc (aiter->size)) == NULL) {
       /*
        * oops. we may not print a message here, because we need these
        * areas (uulib_msgstring) in UUMessage()
        */
       for (aiter=toallocate; aiter->ptr; aiter++) {
-	safe_free (*(aiter->ptr), aiter->size);
+	_FP_free (*(aiter->ptr));
       }
       return UURET_NOMEM;
     }
@@ -438,7 +434,7 @@ UUGetOption (int option, int *ivalue, char *cvalue, int clength)
     result = 0;
     break;
   case UUOPT_VERSION:
-    FP_strncpy (cvalue, uulibversion, clength);
+    _FP_strncpy (cvalue, uulibversion, clength);
     result = 0;
     break;
   case UUOPT_FAST:
@@ -478,7 +474,7 @@ UUGetOption (int option, int *ivalue, char *cvalue, int clength)
     result = uu_overwrite;
     break;
   case UUOPT_SAVEPATH:
-    FP_strncpy (cvalue, uusavepath, clength);
+    _FP_strncpy (cvalue, uusavepath, clength);
     result = 0;
     break;
   case UUOPT_PROGRESS:
@@ -506,7 +502,7 @@ UUGetOption (int option, int *ivalue, char *cvalue, int clength)
     result = uu_tinyb64;
     break;
   case UUOPT_ENCEXT:
-    FP_strncpy (cvalue, uuencodeext, clength);
+    _FP_strncpy (cvalue, uuencodeext, clength);
     result = 0;
     break;
   case UUOPT_REMOVE:
@@ -521,10 +517,6 @@ UUGetOption (int option, int *ivalue, char *cvalue, int clength)
     if (ivalue) *ivalue = uu_dotdot;
     result = uu_dotdot;
     break;
-  case UUOPT_AUTOCHECK:
-    if (ivalue) *ivalue = uu_autocheck;
-    result = uu_autocheck;
-    break;
   default:
     return -1;
   }
@@ -566,8 +558,8 @@ UUSetOption (int option, int ivalue, char *cvalue)
     uu_overwrite      = ivalue;
     break;
   case UUOPT_SAVEPATH:
-    FP_free (uusavepath);
-    uusavepath = FP_strdup (cvalue);
+    _FP_free (uusavepath);
+    uusavepath = _FP_strdup (cvalue);
     break;
   case UUOPT_IGNMODE:
     uu_ignmode = ivalue;
@@ -582,8 +574,8 @@ UUSetOption (int option, int ivalue, char *cvalue)
     uu_tinyb64 = ivalue;
     break;
   case UUOPT_ENCEXT:
-    FP_free (uuencodeext);
-    uuencodeext = FP_strdup (cvalue);
+    _FP_free (uuencodeext);
+    uuencodeext = _FP_strdup (cvalue);
     break;
   case UUOPT_REMOVE:
     uu_remove_input = ivalue;
@@ -594,9 +586,6 @@ UUSetOption (int option, int ivalue, char *cvalue)
   case UUOPT_DOTDOT:
     uu_dotdot = ivalue;
     break;
-  case UUOPT_AUTOCHECK:
-    uu_autocheck = ivalue;
-    break;
   default:
     return UURET_ILLVAL;
   }
@@ -614,7 +603,7 @@ UUstrerror (int code)
  */
 
 int UUEXPORT
-UUSetMsgCallback (void *opaque,
+UUSetMsgCallback (void *opaque, 
 		  void (*func) (void *, char *, int))
 {
   uu_MsgCallback = func;
@@ -722,7 +711,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
   int _count;
   if (!partcount)
     partcount = &_count;
-
+  
   *partcount = 0;
 
   if ((datei = fopen (filename, "rb")) == NULL) {
@@ -732,7 +721,6 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
     return UURET_IOERR;
   }
   UUSETBUF (datei, datei_buf, uu_rbuf);
-  FP_flockfile (datei);
 
   if (fstat (fileno(datei), &finfo) == -1) {
     UUMessage (uulib_id, __LINE__, UUMSG_ERROR,
@@ -752,10 +740,10 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
       UUMessage (uulib_id, __LINE__, UUMSG_WARNING,
 		 uustring (S_OUT_OF_MEMORY), sizeof (itbd));
     }
-    else if ((killem->fname = FP_strdup (filename)) == NULL) {
+    else if ((killem->fname = _FP_strdup (filename)) == NULL) {
       UUMessage (uulib_id, __LINE__, UUMSG_WARNING,
 		 uustring (S_OUT_OF_MEMORY), strlen(filename)+1);
-      FP_free (killem);
+      _FP_free (killem);
     }
     else {
       killem->NEXT = ftodel;
@@ -769,7 +757,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
   progress.fsize    = (long) ((finfo.st_size>0)?finfo.st_size:-1);
   progress.percent  = 0;
   progress.foffset  = 0;
-  FP_strncpy (progress.curfile,
+  _FP_strncpy (progress.curfile,
 	       (strlen(filename)>255)?
 	       (filename+strlen(filename)-255):filename,
 	       256);
@@ -778,16 +766,16 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
   if (fileid == NULL)
     fileid = filename;
 
-  while (!FP_feof (datei) && !ferror (datei)) {
-    /*
+  while (!feof (datei) && !ferror (datei)) {
+    /* 
      * Peek file, or some systems won't detect EOF
      */
-    res = FP_getc (datei);
-    if (FP_feof (datei) || ferror (datei))
+    res = fgetc (datei);
+    if (feof (datei) || ferror (datei))
       break;
     else
       ungetc (res, datei);
-
+    
     if ((loaded = ScanPart (datei, fileid, &sr)) == NULL) {
       if (sr != UURET_NODATA && sr != UURET_OK && sr != UURET_CONT) {
 	UUkillfread (loaded);
@@ -796,7 +784,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
 		     uustring (S_READ_ERROR), filename,
 		     strerror (uu_errno));
 
-	if (uu_autocheck) UUCheckGlobalList ();
+	UUCheckGlobalList ();
 	progress.action = 0;
 	fclose (datei);
         UUCLRBUF (uu_rbuf, datei_buf);
@@ -809,7 +797,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
       UUMessage (uulib_id, __LINE__, UUMSG_ERROR,
 		 uustring (S_READ_ERROR), filename,
 		 strerror (uu_errno = errno));
-      if (uu_autocheck) UUCheckGlobalList ();
+      UUCheckGlobalList ();
       progress.action = 0;
       fclose (datei);
       UUCLRBUF (uu_rbuf, datei_buf);
@@ -840,7 +828,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
       if (uu_fast_scanning && sr != UURET_CONT) break;
       continue;
     }
-
+    
     if ((fload = UUPreProcessPart (loaded, &res)) == NULL) {
       /*
        * no useful data found
@@ -870,7 +858,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
 		 (loaded->end)      ? "end"   : "",
 		 codenames[loaded->uudet]);
     }
-
+    
     if ((res = UUInsertPartToList (fload))) {
       /*
        * couldn't use the data
@@ -878,7 +866,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
       UUkillfile (fload);
 
       if (res != UURET_NODATA) {
-	if (uu_autocheck) UUCheckGlobalList ();
+	UUCheckGlobalList ();
 	progress.action = 0;
 	fclose (datei);
         UUCLRBUF (uu_rbuf, datei_buf);
@@ -906,7 +894,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
     UUMessage (uulib_id, __LINE__, UUMSG_ERROR,
 	       uustring (S_READ_ERROR), filename,
 	       strerror (uu_errno = errno));
-    if (uu_autocheck) UUCheckGlobalList ();
+    UUCheckGlobalList ();
     progress.action = 0;
     fclose (datei);
     UUCLRBUF (uu_rbuf, datei_buf);
@@ -921,7 +909,7 @@ UULoadFileWithPartNo (char *filename, char *fileid, int delflag, int partno, int
 	       uustring (S_NO_DATA_FOUND), filename);
 
   progress.action = 0;
-  if (uu_autocheck) UUCheckGlobalList ();
+  UUCheckGlobalList ();
 
   return UURET_OK;
 }
@@ -969,7 +957,6 @@ UUDecodeFile (uulist *thefile, char *destname)
     return UURET_IOERR;
   }
   UUSETBUF (source, source_buf, uu_rbuf);
-  FP_flockfile (source);
 
   /*
    * for system security, strip setuid/setgid bits from mode
@@ -984,7 +971,7 @@ UUDecodeFile (uulist *thefile, char *destname)
 
   /*
    * Determine the name of the target file according to the rules:
-   *
+   * 
    * IF (destname!=NULL) THEN filename=destname;
    * ELSE
    *   filename = thefile->filename
@@ -1041,7 +1028,7 @@ UUDecodeFile (uulist *thefile, char *destname)
     }
 
   progress.action   = 0;
-  FP_strncpy (progress.curfile,
+  _FP_strncpy (progress.curfile,
 	       (strlen(uugen_fnbuffer)>255)?
 	       (uugen_fnbuffer+strlen(uugen_fnbuffer)-255):uugen_fnbuffer,
 	       256);
@@ -1075,9 +1062,8 @@ UUDecodeFile (uulist *thefile, char *destname)
     return UURET_IOERR;
   }
   UUSETBUF (target, target_buf, uu_wbuf);
-  FP_flockfile (target);
 
-  while (!FP_feof (source)) {
+  while (!feof (source)) {
 
     if (UUBUSYPOLL(ftell(source),progress.fsize)) {
       UUMessage (uulib_id, __LINE__, UUMSG_NOTE,
@@ -1092,7 +1078,7 @@ UUDecodeFile (uulist *thefile, char *destname)
 
     bytes = fread (uugen_inbuffer, 1, 1024, source);
 
-    if (ferror (source) || (bytes == 0 && !FP_feof (source))) {
+    if (ferror (source) || (bytes == 0 && !feof (source))) {
       progress.action = 0;
       UUMessage (uulib_id, __LINE__, UUMSG_ERROR,
 		 uustring (S_READ_ERROR),
@@ -1142,7 +1128,7 @@ UUDecodeFile (uulist *thefile, char *destname)
   }
 
 skip_copy:
-  FP_free (thefile->binfile);
+  _FP_free (thefile->binfile);
   thefile->binfile = NULL;
   thefile->state  &= ~UUFILE_TMPFILE;
   thefile->state  |=  UUFILE_DECODED;
@@ -1169,7 +1155,7 @@ UUInfoFile (uulist *thefile, void *opaque,
    */
 
   if (uu_FileCallback) {
-    if ((res = (*uu_FileCallback) (uu_FileCBArg,
+    if ((res = (*uu_FileCallback) (uu_FileCBArg, 
 				   thefile->thisfile->data->sfname,
 				   uugen_fnbuffer,
 				   1)) != UURET_OK)
@@ -1186,12 +1172,12 @@ UUInfoFile (uulist *thefile, void *opaque,
   else {
     if ((inpfile = fopen (thefile->thisfile->data->sfname, "rb")) == NULL) {
       UUMessage (uulib_id, __LINE__, UUMSG_ERROR,
-		 uustring (S_NOT_OPEN_FILE),
+		 uustring (S_NOT_OPEN_FILE), 
 		 thefile->thisfile->data->sfname,
 		 strerror (uu_errno=errno));
       return UURET_IOERR;
     }
-    FP_strncpy (uugen_fnbuffer, thefile->thisfile->data->sfname, 1024);
+    _FP_strncpy (uugen_fnbuffer, thefile->thisfile->data->sfname, 1024);
   }
 
   /*
@@ -1201,9 +1187,9 @@ UUInfoFile (uulist *thefile, void *opaque,
   fseek (inpfile, thefile->thisfile->data->startpos, SEEK_SET);
   maxpos = thefile->thisfile->data->startpos + thefile->thisfile->data->length;
 
-  while (!FP_feof (inpfile) &&
+  while (!feof (inpfile) && 
 	 (uu_fast_scanning || ftell(inpfile) < maxpos)) {
-    if (FP_fgets (uugen_inbuffer, 511, inpfile) == NULL)
+    if (_FP_fgets (uugen_inbuffer, 511, inpfile) == NULL)
       break;
     uugen_inbuffer[511] = '\0';
 
@@ -1237,7 +1223,7 @@ UUInfoFile (uulist *thefile, void *opaque,
   fclose (inpfile);
 
   if (uu_FileCallback)
-    (*uu_FileCallback) (uu_FileCBArg,
+    (*uu_FileCallback) (uu_FileCBArg, 
 			thefile->thisfile->data->sfname,
 			uugen_fnbuffer, 0);
 
@@ -1246,7 +1232,7 @@ UUInfoFile (uulist *thefile, void *opaque,
 
   return UURET_OK;
 }
-
+	    
 int UUEXPORT
 UURenameFile (uulist *thefile, char *newname)
 {
@@ -1257,14 +1243,14 @@ UURenameFile (uulist *thefile, char *newname)
 
   oldname = thefile->filename;
 
-  if ((thefile->filename = FP_strdup (newname)) == NULL) {
+  if ((thefile->filename = _FP_strdup (newname)) == NULL) {
     UUMessage (uulib_id, __LINE__, UUMSG_ERROR,
 	       uustring (S_NOT_RENAME),
 	       oldname, newname);
     thefile->filename = oldname;
     return UURET_NOMEM;
   }
-  FP_free (oldname);
+  _FP_free (oldname);
   return UURET_OK;
 }
 
@@ -1281,7 +1267,7 @@ UURemoveTemp (uulist *thefile)
 		 thefile->binfile,
 		 strerror (uu_errno = errno));
     }
-    FP_free (thefile->binfile);
+    _FP_free (thefile->binfile);
     thefile->binfile = NULL;
     thefile->state  &= ~UUFILE_TMPFILE;
   }
@@ -1306,10 +1292,10 @@ UUCleanUp (void)
 		 uustring (S_TMP_NOT_REMOVED),
 		 iter->fname, strerror (uu_errno = errno));
     }
-    FP_free (iter->fname);
+    _FP_free (iter->fname);
     ptr  = iter;
     iter = iter->NEXT;
-    FP_free (ptr);
+    _FP_free (ptr);
   }
 
   ftodel = NULL;
@@ -1341,9 +1327,9 @@ UUCleanUp (void)
   UUkilllist (UUGlobalFileList);
   UUGlobalFileList = NULL;
 
-  FP_free (uusavepath);
-  FP_free (uuencodeext);
-  FP_free (sstate.source);
+  _FP_free (uusavepath);
+  _FP_free (uuencodeext);
+  _FP_free (sstate.source);
 
   uusavepath  = NULL;
   uuencodeext = NULL;
@@ -1356,7 +1342,7 @@ UUCleanUp (void)
   while (mssdepth) {
     mssdepth--;
     UUkillheaders (&(multistack[mssdepth].envelope));
-    FP_free (multistack[mssdepth].source);
+    _FP_free (multistack[mssdepth].source);
   }
 
   /*
@@ -1364,7 +1350,7 @@ UUCleanUp (void)
    */
 
   for (aiter=toallocate; aiter->ptr; aiter++) {
-    safe_free (*(aiter->ptr), aiter->size);
+    _FP_free (*(aiter->ptr));
     *(aiter->ptr) = NULL;
   }
 
